# `/app/forms`

These are [WTForms][wtforms] form objects that are used to generate HTML forms and validate input.  All classes here should subclass `flask.ext.wtform.Form`.

## Subdirectories

- `fields`: stores custom [WTForms][wtforms] fields.


[wtforms]: http://wtforms.readthedocs.org/en/latest/